@@ -1,4 +1,5 @@
 import json
+import re
 from functools import lru_cache
 
 import dateutil.parser
@@ -38,7 +39,6 @@ class TypeMeta(type):
 
 class BaseType(metaclass=TypeMeta):
     default_value = None
-    default_sort = None
     choices = ()
     raw_type = None
     element_type = None
@@ -130,8 +130,10 @@ class NumberType(BaseType):
         nums = [
             row[name] for row in data if row and row[name] and abs(row[name] > 0.0001)
         ]
+        dp = get_optimal_decimal_places(nums)
         return {
-            "decimalPlaces": get_optimal_decimal_places(nums),
+            "minimumFractionDigits": dp,
+            "maximumFractionDigits": dp,
             "significantFigures": 3,
             "lowCutOff": 0.0001,
             "highCutOff": 1e10,
@@ -155,18 +157,6 @@ class RegexType(BaseType):
         return value
 
 
-class YearType(NumberType):
-    default_value = timezone.now().year
-    default_sort = ASC
-
-    @staticmethod
-    def _parse(value, choices):
-        res = int(value)
-        if res <= 1:
-            raise Exception("Years must be > 1")
-        return res
-
-
 class DurationType(BaseType):
     default_value = ""
 
@@ -198,8 +188,6 @@ class DurationType(BaseType):
 
 
 class DateTypeMixin:
-    default_sort = ASC
-
     @classmethod
     def _lookups(cls):
         return {
@@ -214,13 +202,21 @@ class DateTypeMixin:
 
     @classmethod
     def _parse(cls, value, choices):
-        res = {
-            dateutil.parser.parse(value, dayfirst=False, yearfirst=False),
-            dateutil.parser.parse(value, dayfirst=True, yearfirst=False),
-            dateutil.parser.parse(value, dayfirst=False, yearfirst=True),
-        }
-        assert len(res) == 1, "Ambiguous value"
-        return timezone.make_aware(res.pop())
+        d8 = r"(\d{8})"
+        d422 = r"(\d{4}[^\d]*\d{2}[^\d]*\d{2})"
+        if re.match(r"[^\d]*(" + d8 + "|" + d422 + ")", value):
+            # looks like some kinda iso date, roll with the defaults
+            res = dateutil.parser.parse(value)
+        else:
+            res = {
+                dateutil.parser.parse(value, dayfirst=False, yearfirst=False),
+                dateutil.parser.parse(value, dayfirst=True, yearfirst=False),
+                dateutil.parser.parse(value, dayfirst=False, yearfirst=True),
+                dateutil.parser.parse(value, dayfirst=True, yearfirst=True),
+            }
+            assert len(res) == 1, "Ambiguous value"
+            res = res.pop()
+        return timezone.make_aware(res)
 
 
 class DateTimeType(DateTypeMixin, BaseType):
@@ -258,75 +254,6 @@ class DateType(DateTypeMixin, BaseType):
         return lambda value: None if value is None else str(value)
 
 
-class WeekDayType(BaseType):
-    default_value = "Monday"
-    default_sort = ASC
-
-    @classmethod
-    def _lookups(cls):
-        return {"equals": cls, "not_equals": cls}
-
-    _days = [
-        "Sunday",
-        "Monday",
-        "Tuesday",
-        "Wednesday",
-        "Thursday",
-        "Friday",
-        "Saturday",
-    ]
-
-    @classmethod
-    def _get_formatter(cls, choices):
-        assert not choices
-        return lambda value: None if value is None else cls._days[value - 1]
-
-    @classmethod
-    def _parse(cls, value, choices):
-        assert not choices
-        for i, v in enumerate(cls._days):
-            if v.lower()[:3] == value.lower()[:3]:
-                return i + 1
-        raise Exception("not a day of the week")
-
-
-class MonthType(BaseType):
-    default_value = "January"
-    default_sort = ASC
-
-    @classmethod
-    def _lookups(cls):
-        return {"equals": cls, "not_equals": cls}
-
-    _months = [
-        "January",
-        "Feburary",
-        "March",
-        "April",
-        "May",
-        "June",
-        "July",
-        "August",
-        "September",
-        "October",
-        "November",
-        "December",
-    ]
-
-    @classmethod
-    def _get_formatter(cls, choices):
-        assert not choices
-        return lambda value: None if value is None else cls._months[value - 1]
-
-    @classmethod
-    def _parse(cls, value, choices):
-        assert not choices
-        for i, v in enumerate(cls._months):
-            if v.lower()[:3] == value.lower()[:3]:
-                return i + 1
-        raise Exception("not a month")
-
-
 class HTMLType(StringType):
     @staticmethod
     def _lookups():
@@ -416,19 +343,12 @@ class ChoiceTypeMixin:
 
     @classmethod
     def _get_formatter(cls, choices):
-        if cls.choices:
-            choices = cls.choices
-
         assert choices
         choices = dict(choices)
-        choices[None] = None
         return lambda value: choices.get(value, value)
 
     @classmethod
     def _parse(cls, value, choices):
-        if cls.choices:
-            choices = cls.choices
-
         assert choices
         choices = {v: k for k, v in choices}
         if value not in choices:
@@ -449,13 +369,21 @@ class NumberChoiceType(ChoiceTypeMixin, BaseType):
 
 
 class IsNullType(ChoiceTypeMixin, BaseType):
-    choices = [(True, "IsNull"), (False, "NotNull")]
+    choices = [(None, "IsNull"), (True, "IsNull"), (False, "NotNull")]
     default_value = choices[0][1]
 
     @staticmethod
     def _lookups():
         return {"equals": IsNullType}
 
+    @classmethod
+    def _get_formatter(cls, choices):
+        return super()._get_formatter(cls.choices)
+
+    @classmethod
+    def _parse(cls, value, choices):
+        return super()._parse(value, cls.choices)
+
 
 class ArrayTypeMixin:
     default_value = None
