@@ -6,7 +6,7 @@ import { getPartsForQuery, getRelUrlForQuery } from "./Query";
 import "./App.css";
 
 function FilterValue(props) {
-  const { lookup, lookupType, onChange, value, field } = props;
+  const { lookup, onChange, value, field } = props;
   const onChangeEvent = (e) => onChange(e.target.value);
   if (props.lookup.type === "boolean")
     return (
@@ -26,7 +26,9 @@ function FilterValue(props) {
     return (
       <select {...{ value }} onChange={onChangeEvent} className="FilterValue">
         {field.choices.map((option) => (
-          <option value={option}>{option}</option>
+          <option key={option} value={option}>
+            {option}
+          </option>
         ))}
       </select>
     );
@@ -100,7 +102,6 @@ function Filter(props) {
           {...{ value, field }}
           onChange={(val) => query.setFilterValue(index, val)}
           lookup={type.lookups[lookup]}
-          lookupType={query.getType(type.lookups[lookup])}
         />
         {errorMessage && <p className="Error">{errorMessage}</p>}
       </td>
